@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
 #
-# Copyright (C) 2021 Joelle Maslak
+# Copyright (C) 2021-2022 Joelle Maslak
 # All Rights Reserved - See License
 #
 
@@ -12,7 +12,7 @@ use strict;
 use warnings;
 
 package App::RouterColorizer;
-$App::RouterColorizer::VERSION = '1.212780';
+$App::RouterColorizer::VERSION = '1.222180';
 use Moose;
 
 use feature 'signatures';
@@ -51,7 +51,7 @@ our @BGCOLORS = (
 our $NUM      = qr/$RE{num}{real}/;
 our $INT      = qr/$RE{num}{int}{-sign => ''}/;
 our $POSINT   = qr/(?!0)$INT/;
-our $LOWLIGHT = qr/ (?: -30\. [0-9]{2} ) | (?: -2 [5-9] \. [0-9]{2} ) /xx;
+our $LOWLIGHT = qr/ (?: -[3-9][0-9]\. [0-9]{1,2} ) | (?: -2 [5-9] \. [0-9]{1,2} ) /xx;
 our $LIGHT    = qr/ (?: $NUM ) | (?: N\/A ) /xx;
 
 our $IPV4CIDR = qr/ $RE{net}{IPv4}
@@ -212,7 +212,7 @@ s/^ ( \Q  Configured maximum total number of routes is \E \d+ \Q, warning limit
     }
 
     my $INTERFACE = qr/ [A-Z] \S+ /xx;
-    my $INTSHORT  = qr/ [A-Z][a-z][0-9] \N+ /xx;
+    my $INTSHORT  = qr/ [A-Z][a-z][0-9] \S* /xx;
 
     # "show int" up/down
     $line =~
@@ -246,7 +246,7 @@ s/^ ( $INTSHORT \s+ \Qadmin down\E \s+ \S+ (?: \s+ \N+)? ) $/$self->_colorize($1
     $line =~
       s/^ ( $INTSHORT \s+ down           \s+ \S+ (?: \s+ \N+)? ) $/$self->_colorize($1, $RED)/exx;
 
-    # "show int transceiver"
+    # "show int transceiver" (Arista)
     $line =~
 s/^ ( $INTSHORT (?: \s+ $LIGHT){4} \s+ $LOWLIGHT \s+ \S+ \s ago ) $/$self->_colorize($1, $RED)/exx;
     $line =~
@@ -254,6 +254,12 @@ s/^ ( $INTSHORT (?: \s+ $LIGHT){5}               \s+ \S+ \s ago ) $/$self->_colo
     $line =~
 s/^ ( $INTSHORT (?: \s+ N\/A  ){6} \s*                          ) $/$self->_colorize($1, $ORANGE)/exx;
 
+    # "show int transceiver" (Cisco)
+    $line =~
+s/^ ( $INTSHORT (?: \s+ $LIGHT){3} \s+ $LOWLIGHT ) \s+ $/$self->_colorize($1, $RED)/exx;
+    $line =~
+s/^ ( $INTSHORT (?: \s+ $LIGHT){4}               ) \s+ $/$self->_colorize($1, $INFO)/exx;
+
     #
     # LLDP Neighbors Detail
     #
@@ -423,7 +429,7 @@ App::RouterColorizer - Colorize router CLI output
 
 =head1 VERSION
 
-version 1.212780
+version 1.222180
 
 =head1 DESCRIPTION
 
@@ -519,7 +525,7 @@ Joelle Maslak <jmaslak@antelope.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Joelle Maslak.
+This software is copyright (c) 2021-2022 by Joelle Maslak.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
